<?php
/**
 * Woo commerce PIK Delivery Setup
 *
 * @link       https://pikdeliery.com.com
 * @since      1.3.6
 *
 * @package    pik-delivery
 * @subpackage pik-delivery/classes
 */


defined('ABSPATH') || exit;

if (!class_exists('PIK_Admin_Settings_Setup')):
	class PIK_Admin_Settings_Setup extends PIK_Admin_Settings
	{
		protected static $_instance = null;

		private $field_form = null;
		private $field_form_props = array();

		// protected $tabs = '';

		public function __construct()
		{
			parent::__construct();
			$this->page_id = 'setup';
		}

		public static function instance()
		{
			if (is_null(self::$_instance)) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}


		public function init()
		{
			$this->render_page();
		}


		public function render_page()
		{
			$this->render_tabs();
			$this->output_content();
		}


		public function output_content()
		{
			$action = isset($_POST['action']) ? sanitize_text_field($_POST['action']) : false;
			$error = false;
			$success = false;

			switch ($action) {
				case 'login':
					$result = PIK_Utils::initiate_login($_POST);
					if (isset($result['success']) && $result['success'] == true && isset($result['token'])) {
						$success = true;
						update_option('pik_logged_in', true);
						update_option('pik_token', sanitize_text_field($result['token']));
					}
					else {
						$error = PIK_Utils::extract_error($result);
					}
					break;
				case 'logout':
					delete_option('pik_logged_in');
					delete_option('pik_token');
					$success = true;
					break;
				case 'save-others':
					if (!isset($_POST['google_api_key']) || !isset($_POST['sync_type'])) {
						$error = __('Please input your google api key and select sync type', PIK_PATH);
					}
					else {
						update_option('pik_google_api_key', sanitize_text_field($_POST['google_api_key']));
						update_option('pik_sync_type', sanitize_text_field($_POST['sync_type']));
						update_option('pik_map_width', sanitize_text_field($_POST['map_width']));
						update_option('pik_map_height', sanitize_text_field($_POST['map_height']));

						
						update_option('pik_moto_class', sanitize_text_field($_POST['moto_class']));
						update_option('pik_carro_class', sanitize_text_field($_POST['carro_class']));
						update_option('pik_pickup_class', sanitize_text_field($_POST['pickup_class']));

						$success = true;
					}
					break;
			}


			$logged_in = get_option('pik_logged_in');
			$google_api_key = get_option('pik_google_api_key');
			$sync_type = get_option('pik_sync_type');
			$map_width = get_option('pik_map_width', 100);
			$map_height = get_option('pik_map_height', 400);

			
			$moto_class = get_option('pik_moto_class', '');
			$carro_class = get_option('pik_carro_class', '');
			$pickup_class = get_option('pik_pickup_class', '');



			$WC_Shipping = new WC_Shipping();			
			$shipping_classes = $WC_Shipping->get_shipping_classes();


			if ($success == true) {
				$this->print_notices(__('Your changes were saved.', PIK_PATH), 'updated', false);
			}

			if ($error != false) {
				$this->print_notices(__($error, PIK_PATH), 'error', false);
			}
			include_once(PIK_PATH . 'templates/admin/setup-template.php');
		}


	// public function save_advanced_settings($settings){
	// 	$result = update_option(THWCFD_Utils::OPTION_KEY_ADVANCED_SETTINGS, $settings, 'no');
	// 	return $result;
	// }

	// if(isset($_POST['save_settings']))
	// 	$this->save_settings();
	}

endif;
