<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://themehigh.com
 *
 * @package    pik-delivery
 * @subpackage pik-delivery/admin
 */

if (!defined('WPINC')) {
	die;
}

if (!class_exists('PIK_Admin')):















	
class PIK_Admin
	{
		private $plugin_name;
		private $version;

		/**
		 * Initialize the class and set its properties.
		 *
		 * @since    2.9.0
		 * @param    string    $plugin_name       The name of this plugin.
		 * @param    string    $version    The version of this plugin.
		 */
		public function __construct($plugin_name, $version)
		{
			$this->plugin_name = $plugin_name;
			$this->version = $version;
		}

		public function define_admin_hooks()
		{

			//show on admin end 
			add_action('woocommerce_admin_order_data_after_shipping_address', array($this, 'pik_display_admin_order_meta'), 10, 1);
			add_action('add_meta_boxes', array($this, 'remove_custom_field_from_order_view'), 10, 1);

			// add ajax to handle create and schedule order
			add_action('wp_ajax_create_schedule_pik_order', array($this, 'create_schedule_pik_order_handler'), 10, 1);
			add_action('wp_ajax_cancel_pik_schedule', array($this, 'cancel_pik_scheduled_order_handler'), 10, 1);

			//Force meta query to be accepted in wc_get_orders (used for pending screen)
			add_filter('woocommerce_get_wp_query_args', function ($wp_query_args, $query_vars) {
				if (isset($query_vars['meta_query'])) {
					$meta_query = isset($wp_query_args['meta_query']) ? $wp_query_args['meta_query'] : [];
					$wp_query_args['meta_query'] = array_merge($meta_query, $query_vars['meta_query']);
				}
				return $wp_query_args;
			}, 10, 2);

		// add_action('woocommerce_admin_order_data_after_order_details', array($this, 'order_data_after_order_details'), 20, 1);
		// add_action('woocommerce_admin_order_data_after_billing_address', array($this, 'order_data_after_billing_address'), 20, 1);
		// add_action('woocommerce_admin_order_data_after_shipping_address', array($this, 'order_data_after_shipping_address'), 20, 1);
		}


		function pik_display_admin_order_meta($order)
		{
			$oid = $order->get_id();
			$shipping = get_post_meta($oid, 'pik_shipping_address', true);

			if (isset($shipping) && !empty($shipping)) { //&& !empty($shipping)

				$synced = get_post_meta($oid, 'pik_order_synced', true);
				$reference = get_post_meta($oid, 'pik_reference_id', true);


				$orderStatus = get_post_meta($oid, 'pik_order_status', true);
				$orderId = get_post_meta($oid, 'pik_order_id', true);
				$scheduleDate = get_post_meta($oid, 'pik_schedule_date', true);
				$scheduleHour = get_post_meta($oid, 'pik_schedule_hour', true);
				$scheduleMinute = get_post_meta($oid, 'pik_schedule_minute', true);

				$creditCards = PIK_Utils::get_credit_cards();
				include_once(PIK_PATH . 'templates/admin/order-view-template.php');
			}
		}

		function cancel_pik_scheduled_order_handler()
		{

			PIK_Utils::write_log($_POST, 'Cancel PIK Scheduled Order Ajax payload');
			if (isset($_POST['order_id'])) {
				$api_result = PIK_Utils::cancel_pik_schedule($_POST['order_id']);
				if (empty($api_result)) {
					echo 'success';
				}
				else {
					echo $api_result;
				}
			}
			else {
				echo 'Unable to submit request, the required field is not provided';
			}
			wp_die();
		}

		function create_schedule_pik_order_handler()
		{
			PIK_Utils::write_log($_POST, 'Schedule/Create Order Ajax payload');

			// 		[type] => create
			// [credit_card] => 124343110  order_id
			if (isset($_POST['type']) && isset($_POST['credit_card']) && isset($_POST['order_id'])) {
				$creditCard = sanitize_text_field($_POST['credit_card']);
				$action = $_POST['type'];
				$oid = $_POST['order_id'];

				$api_result = "Error processing request";
				if ($action == 'create') {
					$api_result = PIK_Utils::send_order_to_pik($oid, $action, $creditCard);
				}
				else {
					$date = $_POST['date'];
					$hour = $_POST['hour'];
					$minute = $_POST['minute'];
					$mergedTime = $_POST['mergedTime'];
					if (!empty($date) && !empty($mergedTime)) {

						$schedule = array('date' => $date, 'time' => $mergedTime);
						$api_result = PIK_Utils::send_order_to_pik($oid, $action, $creditCard, $schedule);
						update_post_meta($oid, 'pik_schedule_date', $date);
						update_post_meta($oid, 'pik_schedule_hour', $hour);
						update_post_meta($oid, 'pik_schedule_minute', $minute);
					}
					else {
						$api_result = "Schedule date or time is empty";
					}
				}
				if (empty($api_result)) {
					echo 'success';
				}
				else {
					echo $api_result;
				}
			}
			else {
				echo 'Unable to submit request, the required field is not provided';
			}

			// Your response in array
			// $array_result = array(
			// 	'data' => 'your data',
			// 	'message' => 'your message'
			// );

			// // Make your array as json
			// wp_send_json($array_result);

			// Don't forget to stop execution afterward.
			wp_die();
		}


		function remove_custom_field_from_order_view()
		{
			remove_meta_box('postcustom', 'shop_order', 'normal');
		}



		public function enqueue_styles_and_scripts($hook)
		{
			// if (strpos($hook, 'pik-delivery') !== false) {

			// }
			$debug_mode = apply_filters('pik_debug_mode', false);
			$suffix = $debug_mode ? '' : '.min';

			$this->enqueue_styles($suffix);
			$this->enqueue_scripts($suffix);
		}

		private function enqueue_styles($suffix)
		{
			wp_enqueue_style('woocommerce_admin_styles');
			wp_enqueue_style('pik-admin-style', PIK_ASSETS_URL_ADMIN . 'css/pik-admin' . '.css', $this->version);
		}

		private function enqueue_scripts($suffix)
		{

			// 'jquery-ui-dialog', 'jquery-ui-sortable', 'jquery-tiptip',
			$deps = array('jquery', 'jquery-ui-core', 'jquery-ui-datepicker', 'woocommerce_admin', 'selectWoo', 'wp-i18n');

			wp_enqueue_script('pik-admin-script', PIK_ASSETS_URL_ADMIN . 'js/pik-admin' . '.js', $deps, $this->version, false);
			wp_set_script_translations('pik-admin-script', 'pik-delivery', dirname(PIK_BASE_NAME) . '/languages/');
			wp_localize_script('pik-admin-script', 'my_ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
		}

		public function admin_menu()
		{
			$capability = PIK_Utils::pik_capability();
			$this->screen_id = add_submenu_page('woocommerce', __('PIK Delivery Woocommerce', 'pik-delivery'),
				__('PIK Delivery Woocommerce', 'pik-delivery'), $capability, 'pik_delivery', array($this, 'output_settings'));

			$page = add_menu_page(
				__('PiK Delivery', 'pik-delivery'),
				'PiK Delivery',
				'manage_options',
				'pik-delivery',
				array($this, 'output_settings'),
				PIK_URL . 'admin/assets/images/wp-plugins/logo.png'
			);
		}

		public function add_screen_id($ids)
		{
			$ids[] = 'woocommerce_page_pik_delivery';
			$ids[] = strtolower(__('WooCommerce', 'pik-delivery')) . 'woocommerce_page_pik_delivery';

			return $ids;
		}

		public function plugin_action_links($links)
		{
			$settings_link = '<a href="' . esc_url(admin_url('admin.php?page=pik_delivery')) . '">' . __('Settings', 'pik-delivery') . '</a>';
			array_unshift($links, $settings_link);
			// $pro_link = '<a style="color:green; font-weight:bold" target="_blank" href="https://www.themehigh.com/product/woocommerce-checkout-field-editor-pro/?utm_source=free&utm_medium=plugin_action_link&utm_campaign=wcfe_upgrade_link">'. __('Get Pro', 'pik-delivery') .'</a>';
			// array_push($links,$pro_link);
			return $links;
		}

		public function get_current_tab()
		{
			return isset($_GET['tab']) ? sanitize_key($_GET['tab']) : 'fields';
		}

		public function output_settings()
		{
			echo '<div class="wrap">';
			echo '<h2></h2>';

			$tab = $this->get_current_tab();

			echo '<div class="pik-main"> 
			<div class="pik-header">
				PIK Delivery
			</div>
			<div class="pik-body">
		  ';
			// --TBD Tab removed 
			/*if ($tab === 'pending') {
			 $advanced_settings = PIK_Admin_Settings_Pending::instance();
			 $advanced_settings->render_page();
			 }
			 elseif ($tab === 'setup') {
			 $pik_plugins = PIK_Admin_Settings_Setup::instance();
			 $pik_plugins->render_page();
			 }
			 else {
			 $advanced_settings = PIK_Admin_Settings_Overview::instance();
			 $advanced_settings->render_page();
			 } */
			$pik_plugins = PIK_Admin_Settings_Setup::instance();
			$pik_plugins->render_page();
			echo '</div> </div>';
			echo '</div>';
		}

	}

endif;