<?php
/**
 * The file that defines the core plugin class.
 *
 * @link       https://themehigh.com
 * @since      1.5.0
 *
 * @package    pik-delivery
 * @subpackage pik-delivery/includes
 */
if (!defined('WPINC')) {
    die;
}

if (!class_exists('PIK')):

    class PIK
    {
        protected $plugin_name;
        protected $version;
        const TEXT_DOMAIN = 'pik-delivery';

        public function __construct()
        {
            if (defined('PIK_VERSION')) {
                $this->version = PIK_VERSION;
            }
            else {
                $this->version = '1.0.0';
            }
            $this->plugin_name = 'pik-delivery';

            $this->load_dependencies();
            $this->define_admin_hooks();
            $this->define_public_hooks();

            add_action('init', array($this, 'init'));
        }

        //TBD
        private function load_dependencies()
        {
            if (!function_exists('is_plugin_active')) {
                include_once ABSPATH . 'wp-admin/includes/plugin.php';
            }

            require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-pik-autoloader.php';

            require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-pik-admin.php';
            require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-pik-public-checkout.php';

        }

        private function define_admin_hooks()
        {
            $plugin_admin = new PIK_Admin($this->get_plugin_name(), $this->get_version());

            add_action('admin_enqueue_scripts', array($plugin_admin, 'enqueue_styles_and_scripts'));
            add_action('admin_menu', array($plugin_admin, 'admin_menu'));
            add_filter('woocommerce_screen_ids', array($plugin_admin, 'add_screen_id'));

            add_filter('plugin_action_links_' . PIK_BASE_NAME, array($plugin_admin, 'plugin_action_links'));

            //Admin order details view hook
            add_action('after_setup_theme', array($plugin_admin, 'define_admin_hooks'));

            add_action('wp_ajax_hide_pik_admin_notice', array($this, 'hide_pik_admin_notice'));
        }

        private function define_public_hooks()
        {
            $plugin_checkout = new PIK_Public_Checkout($this->get_plugin_name(), $this->get_version());
            add_action('wp_enqueue_scripts', array($plugin_checkout, 'enqueue_styles_and_scripts'));
            add_action('after_setup_theme', array($plugin_checkout, 'define_public_hooks'));
        }

        public function init()
        {
            $this->define_constants();
        }

        private function define_constants()
        {
            !defined('PIK_ASSETS_URL_ADMIN') && define('PIK_ASSETS_URL_ADMIN', PIK_URL . 'admin/assets/');
            !defined('PIK_ASSETS_URL_PUBLIC') && define('PIK_ASSETS_URL_PUBLIC', PIK_URL . 'public/assets/');
        }

        /**
         * The name of the plugin used to uniquely identify it within the context of
         * WordPress and to define internationalization functionality.
         *
         * @return    string    The name of the plugin.
         */
        public function get_plugin_name()
        {
            return $this->plugin_name;
        }

        /**
         * Retrieve the version number of the plugin.
         *
         * @return    string    The version number of the plugin.
         */
        public function get_version()
        {
            return $this->version;
        }

        public function hide_pik_admin_notice()
        {
            check_ajax_referer('pik_notice_security', 'pik_review_nonce');

            // $capability = THWEPOF_Utils::wepo_capability();
            // if (!current_user_can($capability)) {
            //     wp_die(-1);
            // }

            $now = time();
        // update_user_meta(get_current_user_id(), 'pik_review_skipped', true);
        // update_user_meta(get_current_user_id(), 'pik_review_skipped_time', $now);
        }

    }

endif;
