<?php
/**
 * The common utility functionalities for the plugin.
 *
 * @link       https://themehigh.com
 * @since      1.5.0
 *
 * @package    pik-delivery
 * @subpackage pik-delivery/public
 */
if (!defined('WPINC')) {
	die;
}

if (!class_exists('PIK_Utils')):
	class PIK_Utils
	{
		public static function extract_error($obj)
		{
			if (!isset($obj)) {
				return __('Fatal Error, please contact admin', PIK_PATH);
			}
			if (isset($obj['message'])) {
				return $obj['message'];
			}
			if (isset($obj['errorCode'])) {
				return $obj['errorCode'];
			}
			return __('An error occured, please try again later', PIK_PATH);
		}

		public function __construct()
		{

		}

		public static function pik_capability()
		{
			$allowed = array('manage_woocommerce', 'manage_options');
			$capability = apply_filters('pik_required_capability', 'manage_woocommerce');

			if (!in_array($capability, $allowed)) {
				$capability = 'manage_woocommerce';
			}
			return $capability;
		}


		public static function initiate_login($data)
		{

			$result = array("success" => false, "message" => "Please input username and password");

			if (!isset($data['pik_email']) || !isset($data['pik_password'])) {
				return $result;
			}

			$email = sanitize_email($data['pik_email']);
			$password = sanitize_text_field($data['pik_password']);
			$payload = array("email" => $email, "password" => $password);


			$response = wp_remote_post(PIK_API_ROOT . "/business/auth/signin",
				array(
				'headers' => array(
					'Content-Type' => 'application/json',
				),
				'timeout' => 60,
				'body' => json_encode($payload))
			);

			$api_response = json_decode(wp_remote_retrieve_body($response), true);
			$result = $api_response;
			return $result;
		}


		public static function get_pik_pricing($address, $vehicle)
		{

			$route = array('address' => $address);
			$pik_token = get_option('pik_token');
			$payload = array("vehicleType" => $vehicle, "route" => $route);

			PIK_Utils::write_log($pik_token, "PIK Buines Token");
			$response = wp_remote_post(PIK_API_ROOT . "/business/ecommerce/calculate-price",
				array(
				'headers' => array(
					'Content-Type' => 'application/json',
					'Authorization' => 'Bearer ' . $pik_token
				),
				'timeout' => 60,
				'body' => json_encode($payload))
			);

			$api_response = json_decode(wp_remote_retrieve_body($response), true);
			if (!isset($api_response) || !$api_response['success'])
				return null;
			PIK_Utils::write_log($api_response, 'PIK API Response');
			return $api_response['combinedPrice']['total'];
		}


		public static function cancel_pik_schedule($order_id)
		{
			try {
				$pikOrderId = get_post_meta($order_id, 'pik_order_id', true);
				if (!isset($pikOrderId) || empty($pikOrderId)) {
					return "This order wasn't sycned with PIK Delivery";
				}
				$payload = array(
					'pikOrderId' => $pikOrderId
				);
				$pik_token = get_option('pik_token');
				$response = wp_remote_post(PIK_API_ROOT . "/business/ecommerce/cancel-schedule",
					array(
					'headers' => array(
						'Content-Type' => 'application/json',
						'Authorization' => 'Bearer ' . $pik_token
					),
					'timeout' => 60,
					'body' => json_encode($payload))
				);

				$api_response = json_decode(wp_remote_retrieve_body($response), true);
				PIK_Utils::write_log($api_response, "PIK Cancel Schedule Respose $order_id");
				if (!isset($api_response) || !$api_response['success'])
					return PIK_Utils::extract_error($api_response);

				PIK_Utils::write_log("Removing schedule info  $order_id");

				delete_post_meta($order_id, 'pik_order_id');
				delete_post_meta($order_id, 'pik_order_status');
				delete_post_meta($order_id, 'pik_schedule_date');
				delete_post_meta($order_id, 'pik_schedule_hour');
				delete_post_meta($order_id, 'pik_schedule_minute');

			}
			catch (Exception $ex) {
				PIK_Utils::write_log($ex, "Cancel Schedule Error $order_id");
				return "An exception occured while trying to process your request, please contact the admin";
			}

		}


		public static function send_order_to_pik($order_id, $action = null, $creditCard = null, $schedule = null)
		{
			PIK_Utils::write_log("Sending Order to PIK Delivery  ===> $order_id");
			$order = wc_get_order($order_id);
			$order_data = $order->get_data();
			$items = $order->get_items();

			$shipping_address = get_post_meta($order_id, 'pik_shipping_address', true);
			if (!isset($shipping_address)) {
				PIK_Utils::write_log("PIK Shipping Address Not found");
				return "PIK Shipping Address Not found";
			}

			// PIK_Utils::write_log($order_data, "Order Data");

			$order_date = $order->get_date_created()->date('Y-m-d H:i:s');
			$shipping_name = $order_data['shipping']['first_name'] . ' ' . $order_data['shipping']['last_name'];
			$route = array('address' => json_decode($shipping_address));
			$order_items = array();

			$carro_class = get_option('pik_carro_class', '');
			$pickup_class = get_option('pik_pickup_class', '');
			$vehicle = PIK_DEFAULT_VEHICLE;

			foreach ($items as $item_key => $item) {
				$item_name = $item['name'];
				$total = $item['total'];
				$product_id = $item->get_product_id();
				$quantity = $item->get_quantity();
				$image = get_the_post_thumbnail_url($product_id);
				$order_items[] = array('name' => $item_name, 'total' => $total, 'productId' => $product_id, 'quantity' => $quantity, 'image' => $image);
				$product = $item->get_product();
				//Handle vehilce stuff
				$classid = $product->get_shipping_class_id();
				// PIK_Utils::write_log($classid,  "Product Class ID ");
				if ($classid == $pickup_class) {
					$vehicle = 'Pickup';
					break;
				}
				if ($classid == $carro_class) {
					$vehicle = 'Carro';
					break;
				}

			}

			$payload = array(
				'type' => "WooCommerce",
				'orderId' => $order_id,
				'orderDate' => $order_date,
				'shippingName' => $shipping_name,
				'totalCost' => $order_data['total'],
				'shippingTotal' => $order_data['shipping_total'],
				'orderItems' => $order_items,
				'route' => $route,
				"vehicleType" => $vehicle,
				'phone' => $order_data['billing']['phone'],
				'email' => $order_data['billing']['email'],
				'action' => $action,
				'creditCard' => $creditCard,
				'schedule' => $schedule
			);
			PIK_Utils::write_log($payload, 'Request Payload');

			$pik_token = get_option('pik_token');
			$response = wp_remote_post(PIK_API_ROOT . "/business/ecommerce/sync-order",
				array(
				'headers' => array(
					'Content-Type' => 'application/json',
					'Authorization' => 'Bearer ' . $pik_token
				),
				'timeout' => 60,
				'body' => json_encode($payload))
			);

			$api_response = json_decode(wp_remote_retrieve_body($response), true);
			PIK_Utils::write_log($api_response, 'PIK Sync Order Response');
			if (!isset($api_response) || !$api_response['success'])
				return PIK_Utils::extract_error($api_response);

			//save to meta_data
			PIK_Utils::write_log('saving response');
			update_post_meta($order_id, 'pik_order_synced', true);
			update_post_meta($order_id, 'pik_reference_id', $api_response['referenceId']);

			if (isset($api_response['pikOrderId'])) {
				update_post_meta($order_id, 'pik_order_id', $api_response['pikOrderId']);
				update_post_meta($order_id, 'pik_order_status', $action);
			}
		}

		public static function delete_pik_order($order_id)
		{
			delete_post_meta($order_id, 'pik_reference_id', true);
		}

		public static function write_log($log, $title = '')
		{
			if (true === WP_DEBUG) {
				if (is_array($log) || is_object($log)) {
					error_log($title . ' ===> ' . print_r($log, true));
				}
				else {
					error_log($title . ' ===> ' . $log);
				}
			}
		}


		//Vehicle picking...consider the most expensive (pickup --> carro ---> moto) first
		public static function get_package_vehicle_type($package)
		{
			$moto_class = get_option('pik_moto_class', '');
			$carro_class = get_option('pik_carro_class', '');
			$pickup_class = get_option('pik_pickup_class', '');

			$vehicle = PIK_DEFAULT_VEHICLE;
			foreach ($package['contents'] as $cart_item) {
				$classid = $cart_item['data']->get_shipping_class_id();
				if ($classid == $pickup_class) {
					$vehicle = 'Pickup';
					break;
				}
				if ($classid == $carro_class) {
					$vehicle = 'Carro';
					break;
				}
			}
			return $vehicle;
		}

		public static function get_credit_cards()
		{
			try {
				$pik_token = get_option('pik_token');
				$response = wp_remote_get(PIK_API_ROOT . "/business/order/credit-cards",
					array(
					'headers' => array(
						'Content-Type' => 'application/json',
						'Authorization' => 'Bearer ' . $pik_token
					),
					'timeout' => 60,
					// 'body' => json_encode($payload),
				)
				);

				$api_response = json_decode(wp_remote_retrieve_body($response), true);
				PIK_Utils::write_log($api_response, 'PIK Get Credit Card Response');
				if (!isset($api_response) || !$api_response['success'])
					return array();
				return $api_response['creditCards'];

			}
			catch (Exception $ex) {
				PIK_Utils::write_log($ex, 'Get Credit card exception');
				return array();
			}
		}


		public static function print_notices($msg, $type = 'updated', $return = false)
		{
			$notice = '<div class="pik-notice ' . $type . '"><p>' . $msg . '</p></div>';
			if (!$return) {
				echo $notice;
			}
			return $notice;
		}
	}

endif;
