<?php
/**
 * Woo Checkout Field Editor Public
 *
 * @link       https://themehigh.com
 * @since      1.3.6
 *
 * @package    pik-delivery
 * @subpackage pik-delivery/public
 */

defined('ABSPATH') || exit;

if (!class_exists('PIK_Public_Checkout')):
	class PIK_Public_Checkout
	{
		public function __construct()
		{

		}

		public function enqueue_styles_and_scripts()
		{

			//Only include onc heckout
			if (is_checkout()) {
				$in_footer = true; // apply_filters('pik_enqueue_script_in_footer', true);
				$deps = array('jquery', 'selectWoo');

				$debug_mode = apply_filters('pik_debug_mode', false);
				$suffix = ''; // $debug_mode ? '' : '.min';
				$google_api_key = get_option('pik_google_api_key');
				wp_enqueue_style('pik-checkout-style', PIK_ASSETS_URL_PUBLIC . 'css/pik-public' . $suffix . '.css', PIK_VERSION);
				//Google map key
				wp_register_script(
					PIK_PATH . '-google-maps-js',
					GOOGLE_MAP_API . $google_api_key . '&libraries=places',
					array(),
					PIK_VERSION,
					false
				);
				wp_enqueue_script(PIK_PATH . '-google-maps-js');
				wp_register_script('pik-checkout-script', PIK_ASSETS_URL_PUBLIC . 'js/pik-public' . $suffix . '.js', $deps, PIK_VERSION, $in_footer);
				wp_enqueue_script('pik-checkout-script');
			}
		}


		public function define_public_hooks()
		{
			add_filter('woocommerce_checkout_fields', array($this, 'pik_prepare_checkout_field'), 10, 1);
			add_action('woocommerce_after_checkout_billing_form', array($this, 'pik_render_checkout_map'), 20, 2);
			add_filter('woocommerce_package_rates', array($this, 'update_shipping_cost'), 20, 2);

			//Validate the fields 
			add_action('woocommerce_after_checkout_validation', array($this, 'pik_validate_checkout_field'), 10, 2);

			//save custom data
			add_action('woocommerce_checkout_update_order_meta', array($this, 'pik_update_order_meta'), 10, 2);

			//after order processed 
			add_action('woocommerce_checkout_order_processed', array($this, 'pik_order_proceed'), 10);

		}


		public function pik_prepare_checkout_field($fields)
		{
			//This field will be the json string address by the user on checkout
			//hidden not workingin some cases
			$fields['billing']['pik_shipping_address'] = array(
				'type' => 'text',
				'label' => __('PIK Shipping Address', PIK_PATH),
				'placeholder' => __('PIK Shipping Address', PIK_PATH),
				'required' => false,
				'class' => array('hidden'),
				'clear' => true,
			);
			//TBD show hidden billing phone
			// $fields['billing']['billing_phone']['hidden'] = false;
			return $fields;
		}

		//Render map on the checkout page
		public function pik_render_checkout_map()
		{
			$pik_token = get_option('pik_token');
			$map_width = get_option('pik_map_width', 100);
			$map_height = get_option('pik_map_height', 400);
			$logged_in = get_option('pik_logged_in');
			$google_api_key = get_option('pik_google_api_key');

			if (empty($pik_token) || empty($logged_in) || empty($google_api_key)) {
				echo 'You are not logged into the PIK business. Please do so in the admin setup';
			}
			else {
				include_once(PIK_PATH . 'templates/public/checkout-template.php');
			}
		}

		function update_shipping_cost($rates, $package)
		{
			if (!isset($_POST['post_data']) && !isset($_POST['pik_shipping_address'])) { //|| is_admin()
				return $rates;
			}
			try {
				if (isset($_POST['pik_shipping_address'])) {
					$pik_address = json_decode(stripslashes($_POST['pik_shipping_address']));
				}
				else {
					//parse post data
					parse_str($_POST['post_data'], $post_data);
					if (!isset($post_data['pik_shipping_address'])) {
						return $rates;
					}
					$pik_address = json_decode($post_data['pik_shipping_address']);
				}

				if (!isset($pik_address) || empty($pik_address)) {
					return $rates;
				}

				//=======================================================Getting The Vehicle type =================
		
				$vehicle = PIK_Utils::get_package_vehicle_type($package);

				PIK_Utils::write_log("Done Getting the Vehicle $vehicle");

				$cost = PIK_Utils::get_pik_pricing($pik_address, $vehicle);
				if ($cost == null)
					return $rates;

				//Calculate the shipping from pik 
				// PIK_Utils::write_log($post_data);
				foreach ($rates as $rate_key => $rate) {
					if($rate->method_id == 'local_pickup') {
						continue;
					}
					$rates[$rate_key]->cost = $cost;
					$rates[$rate_key]->label = "";// "El envío se hará con PIK Delivery";  //$rate->label . ' (PIK Delivery)'; //$rate->label .
				// if ($rate->method_id == 'flat_rate') {
				// 	$rates[$rate_key]->cost = $cost;
				// 	$rates[$rate_key]->label = $rate->label .  ' (PIK Delivery)'; //$rate->label .
				// }
				}
				return $rates;
			}
			catch (Exception $ex) {
				PIK_Utils::write_log($ex, 'PIK Rate Exception');
				return $rates;
			}
		}

		function pik_validate_checkout_field($fields, $errors)
		{
			//This is just in case the field was made optional in the settings 
			if (isset($fields['pik_shipping_address']) && !empty($fields['pik_shipping_address'])) {
				if (!isset($fields['billing_phone']) || empty($fields['billing_phone'])) {
					$errors->add('validation', __('Billing Phone is required'));
				}
			}
		}



		//Update the post meta data
		function pik_update_order_meta($order_id)
		{
			if (isset($_POST['pik_shipping_address']) && !empty($_POST['pik_shipping_address'])) {
				update_post_meta($order_id, 'pik_shipping_address', sanitize_text_field($_POST['pik_shipping_address']));
			}
			else {
				PIK_Utils::delete_pik_order($order_id);
			}
		}



		function pik_order_proceed($order_id)
		{
			$sync_type = get_option('pik_sync_type');
			if ($sync_type == 'automatic') {
				PIK_Utils::send_order_to_pik($order_id);
			}
		}






	
}

endif;
